Index: include/lar.h
===================================================================
--- include/lar.h	(revision 597)
+++ include/lar.h	(working copy)
@@ -67,6 +67,7 @@
 	 * 0 = no compression
 	 * 1 = lzma
 	 * 2 = nrv2b
+	 * 3 = zeroes
 	 */
 	u32 compression;
 	u64 entry;
Index: lib/lar.c
===================================================================
--- lib/lar.c	(revision 597)
+++ lib/lar.c	(working copy)
@@ -170,6 +170,12 @@
 		return 0;
 	}
 #endif
+	/* zeroes */
+	if (archive->compression == 3) {
+		unsigned long tmp;
+		memset(archive->start, 0, archive->reallen);
+		return 0;
+	}
 	printk(BIOS_INFO, "LAR: Compression algorithm #%i not supported!\n", archive->compression);
 	return -1;
 }
Index: util/lar/lar.h
===================================================================
--- util/lar/lar.h	(revision 597)
+++ util/lar/lar.h	(working copy)
@@ -75,6 +75,7 @@
 	 * 0 = no compression
 	 * 1 = lzma
 	 * 2 = nrv2b
+	 * 3 = zeroes
 	 */
 	u32 compression;
 	u64 entry;
@@ -91,7 +92,7 @@
 	u32 size; /**< Size of the mmaped file */
 };
 
-enum compalgo { none = 0, lzma = 1, nrv2b = 2 };
+enum compalgo { none = 0, lzma = 1, nrv2b = 2, zeroes = 3 };
 
 typedef void (*compress_func) (char *, int, char *, int *);
 typedef void (*uncompress_func) (char *, int, char *, int);
@@ -100,26 +101,31 @@
 void do_no_compress(char *in, int in_len, char *out, int *out_len);
 void do_lzma_compress(char *in, int in_len, char *out, int *out_len);
 void do_nrv2b_compress(char *in, int in_len, char *out, int *out_len);
+void do_zeroes_compress(char *in, int in_len, char *out, int *out_len);
 
 void uncompress_impossible(char *dst, int dst_len, char *src, int src_len);
 void do_no_uncompress(char *dst, int dst_len, char *src, int src_len);
 void do_lzma_uncompress(char *dst, int dst_len, char *src, int src_len);
 void do_nrv2b_uncompress(char *dst, int dst_len, char *src, int src_len);
+void do_zeroes_uncompress(char *dst, int dst_len, char *src, int src_len);
 
 static compress_func compress_functions[] = {
 	do_no_compress,
 	do_lzma_compress,
 	do_nrv2b_compress,
+	do_zeroes_compress,
 };
 
 static uncompress_func uncompress_functions[] = {
 	do_no_uncompress,
 	do_lzma_uncompress,
 	do_nrv2b_uncompress,
+	do_zeroes_uncompress,
 };
 
 static const char *algo_name[] = {
 	"",
 	"lzma",
 	"nrv2b",
+	"zeroes",
 };
Index: util/lar/lib.c
===================================================================
--- util/lar/lib.c	(revision 597)
+++ util/lar/lib.c	(working copy)
@@ -57,6 +57,24 @@
 }
 
 /**
+ * The zeroes "compress" hook
+ */
+void do_zeroes_compress(char *in, int in_len, char *out, int *out_len)
+{
+	out[0] = 0;
+	out_len[0] = 1;
+}
+
+/**
+ * The zeroes "uncompress" hook
+ */
+
+void do_zeroes_uncompress(char *dst, int dst_len, char *src, int src_len)
+{
+	memset(dst, 0, dst_len);
+}
+
+/**
  * The default "uncompress" hook to call when no other compression is used
  */
 
Index: util/lar/stream.c
===================================================================
--- util/lar/stream.c	(revision 597)
+++ util/lar/stream.c	(working copy)
@@ -147,7 +147,7 @@
 				fprintf(stderr, "Dropping empty section\n");
 			continue;
 		}
-		thisalgo = algo;
+		thisalgo = zeroes;
 		if (verbose())
 			fprintf(stderr,  "New section addr %#x size %#x\n",
 			(u32)shdr[i].sh_addr, (u32)shdr[i].sh_size);
